==> buildpack-client-0.0.12-sources.jar: dev/snowdrop/buildpack/config/PlatformConfigFluentImpl.java <==
package dev.snowdrop.buildpack.config;

import dev.snowdrop.buildpack.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class PlatformConfigFluentImpl<A extends dev.snowdrop.buildpack.config.PlatformConfigFluent<A>> extends dev.snowdrop.buildpack.builder.BaseFluent<A> implements dev.snowdrop.buildpack.config.PlatformConfigFluent<A>{
  public PlatformConfigFluentImpl() {
  }
  public PlatformConfigFluentImpl(dev.snowdrop.buildpack.config.PlatformConfig instance) {
    this.withPlatformLevel(instance.getPlatformLevel()); 
    this.withLifecycleImage(instance.getLifecycleImage()); 
    this.withEnvironment(instance.getEnvironment()); 
    this.withTrustBuilder(instance.getTrustBuilder()); 
  }
  private java.lang.String platformLevel;
  private java.util.Map<java.lang.String,java.lang.String> environment;
  private dev.snowdrop.buildpack.config.ImageReference lifecycleImage;
  private java.lang.Boolean trustBuilder;
  public java.lang.String getPlatformLevel() {
    return this.platformLevel;
  }
  public A withPlatformLevel(java.lang.String platformLevel) {
    this.platformLevel=platformLevel; return (A) this;
  }
  public java.lang.Boolean hasPlatformLevel() {
    return this.platformLevel != null;
  }
  public A addToEnvironment(java.lang.String key,java.lang.String value) {
    if(this.environment == null && key != null && value != null) { this.environment = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.environment.put(key, value);} return (A)this;
  }
  public A addToEnvironment(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.environment == null && map != null) { this.environment = new java.util.LinkedHashMap(); }
    if(map != null) { this.environment.putAll(map);} return (A)this;
  }
  public A removeFromEnvironment(java.lang.String key) {
    if(this.environment == null) { return (A) this; }
    if(key != null && this.environment != null) {this.environment.remove(key);} return (A)this;
  }
  public A removeFromEnvironment(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.environment == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.environment != null){this.environment.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.String> getEnvironment() {
    return this.environment;
  }
  public <K,V>A withEnvironment(java.util.Map<java.lang.String,java.lang.String> environment) {
    if (environment == null) { this.environment =  null;} else {this.environment = new java.util.LinkedHashMap(environment);} return (A) this;
  }
  public java.lang.Boolean hasEnvironment() {
    return this.environment != null;
  }
  public dev.snowdrop.buildpack.config.ImageReference getLifecycleImage() {
    return this.lifecycleImage;
  }
  public A withLifecycleImage(dev.snowdrop.buildpack.config.ImageReference lifecycleImage) {
    this.lifecycleImage=lifecycleImage; return (A) this;
  }
  public java.lang.Boolean hasLifecycleImage() {
    return this.lifecycleImage != null;
  }
  public A withNewLifecycleImage(java.lang.String reference) {
    return (A)withLifecycleImage(new ImageReference(reference));
  }
  public java.lang.Boolean getTrustBuilder() {
    return this.trustBuilder;
  }
  public A withTrustBuilder(java.lang.Boolean trustBuilder) {
    this.trustBuilder=trustBuilder; return (A) this;
  }
  public java.lang.Boolean hasTrustBuilder() {
    return this.trustBuilder != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PlatformConfigFluentImpl that = (PlatformConfigFluentImpl) o;
    if (platformLevel != null ? !platformLevel.equals(that.platformLevel) :that.platformLevel != null) return false;
    if (environment != null ? !environment.equals(that.environment) :that.environment != null) return false;
    if (lifecycleImage != null ? !lifecycleImage.equals(that.lifecycleImage) :that.lifecycleImage != null) return false;
    if (trustBuilder != null ? !trustBuilder.equals(that.trustBuilder) :that.trustBuilder != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(platformLevel,  environment,  lifecycleImage,  trustBuilder,  super.hashCode());
  }
  
}

==> buildpack-client-0.0.14-sources.jar: dev/snowdrop/buildpack/config/PlatformConfigFluentImpl.java <==
package dev.snowdrop.buildpack.config;

import dev.snowdrop.buildpack.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class PlatformConfigFluentImpl<A extends dev.snowdrop.buildpack.config.PlatformConfigFluent<A>> extends dev.snowdrop.buildpack.builder.BaseFluent<A> implements dev.snowdrop.buildpack.config.PlatformConfigFluent<A>{
  public PlatformConfigFluentImpl() {
  }
  public PlatformConfigFluentImpl(dev.snowdrop.buildpack.config.PlatformConfig instance) {
    this.withPlatformLevel(instance.getPlatformLevel()); 
    this.withLifecycleImage(instance.getLifecycleImage()); 
    this.withEnvironment(instance.getEnvironment()); 
    this.withTrustBuilder(instance.getTrustBuilder()); 
    this.withPhaseDebugScript(instance.getPhaseDebugScript()); 
  }
  private java.lang.String platformLevel;
  private java.util.Map<java.lang.String,java.lang.String> environment;
  private dev.snowdrop.buildpack.config.ImageReference lifecycleImage;
  private java.lang.Boolean trustBuilder;
  private java.lang.String phaseDebugScript;
  public java.lang.String getPlatformLevel() {
    return this.platformLevel;
  }
  public A withPlatformLevel(java.lang.String platformLevel) {
    this.platformLevel=platformLevel; return (A) this;
  }
  public java.lang.Boolean hasPlatformLevel() {
    return this.platformLevel != null;
  }
  public A addToEnvironment(java.lang.String key,java.lang.String value) {
    if(this.environment == null && key != null && value != null) { this.environment = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.environment.put(key, value);} return (A)this;
  }
  public A addToEnvironment(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.environment == null && map != null) { this.environment = new java.util.LinkedHashMap(); }
    if(map != null) { this.environment.putAll(map);} return (A)this;
  }
  public A removeFromEnvironment(java.lang.String key) {
    if(this.environment == null) { return (A) this; }
    if(key != null && this.environment != null) {this.environment.remove(key);} return (A)this;
  }
  public A removeFromEnvironment(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.environment == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.environment != null){this.environment.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.String> getEnvironment() {
    return this.environment;
  }
  public <K,V>A withEnvironment(java.util.Map<java.lang.String,java.lang.String> environment) {
    if (environment == null) { this.environment =  null;} else {this.environment = new java.util.LinkedHashMap(environment);} return (A) this;
  }
  public java.lang.Boolean hasEnvironment() {
    return this.environment != null;
  }
  public dev.snowdrop.buildpack.config.ImageReference getLifecycleImage() {
    return this.lifecycleImage;
  }
  public A withLifecycleImage(dev.snowdrop.buildpack.config.ImageReference lifecycleImage) {
    this.lifecycleImage=lifecycleImage; return (A) this;
  }
  public java.lang.Boolean hasLifecycleImage() {
    return this.lifecycleImage != null;
  }
  public A withNewLifecycleImage(java.lang.String s) {
    return (A)withLifecycleImage(new ImageReference(s));
  }
  public java.lang.Boolean getTrustBuilder() {
    return this.trustBuilder;
  }
  public A withTrustBuilder(java.lang.Boolean trustBuilder) {
    this.trustBuilder=trustBuilder; return (A) this;
  }
  public java.lang.Boolean hasTrustBuilder() {
    return this.trustBuilder != null;
  }
  public java.lang.String getPhaseDebugScript() {
    return this.phaseDebugScript;
  }
  public A withPhaseDebugScript(java.lang.String phaseDebugScript) {
    this.phaseDebugScript=phaseDebugScript; return (A) this;
  }
  public java.lang.Boolean hasPhaseDebugScript() {
    return this.phaseDebugScript != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PlatformConfigFluentImpl that = (PlatformConfigFluentImpl) o;
    if (platformLevel != null ? !platformLevel.equals(that.platformLevel) :that.platformLevel != null) return false;
    if (environment != null ? !environment.equals(that.environment) :that.environment != null) return false;
    if (lifecycleImage != null ? !lifecycleImage.equals(that.lifecycleImage) :that.lifecycleImage != null) return false;
    if (trustBuilder != null ? !trustBuilder.equals(that.trustBuilder) :that.trustBuilder != null) return false;
    if (phaseDebugScript != null ? !phaseDebugScript.equals(that.phaseDebugScript) :that.phaseDebugScript != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(platformLevel,  environment,  lifecycleImage,  trustBuilder,  phaseDebugScript,  super.hashCode());
  }
  
}
